Select files to process Or, select a json file with a precomputed list of images. {{progress.done}} images done!

Image | Sample ID | Date/Time | Filename | Latitute | Longitude
--- | --- | --- | --- | --- | ---
|  |  | {{image.datestr}} | {{image.filename}} | {{image.lat.toFixed(5)}} | {{image.lng.toFixed(5)}}

# Image Sorter

## Help

1. Move all images you want to sort to one directory, e.g. ~/images.
2. Click the Browse... button at the top of the page, and select all images in this directory
3. The backend will now scan your images for metadata and QRcodes. Monitor the progress bar.
4. Wait until the progress bar disappears. The table is now sorted by time, and buttons with further actions will appear at the top (If this doesn't happen and the progress bar seems stuck, it's a bug, contact Kevin).
5. Go through the rows of the table. For each image:
   - if the ID box is empty, click it to edit. If a QRcode was scanned correctly within N seconds (configure below), this will autofill. See also the "autofill everything" button at the top of the pages, which is basically clicking each empty box automatically.
   - Check each ID. The id is what will be used to sort the image, so make sure it's correct.
   - Click the thumbnail image to expand it, if needed
   - If the image should not be sorted, click the rubbish bin item to ignore it. This will not delete the image from your computer.
6. Once you are happy with the IDs assigned to each image, click the "download renamer script" button at the top. This script is a bash script to rename all images with valid IDs (if the ID box is still empty when you download the script, the image will not be moved). To execute this script:
   - Download it to the same directory as your images. If your browser says something like "this file may harm your computer", ignore it, it's just a bash script.
   - Open Terminal or similar (OSX and Linux).
   - cd to your image directory (`cd /path/to/images`)
   - run `bash -xe SCRIPT_NAME.sh`. The script should be called renamer.sh by default but you can change this when downloading.
   - For windows, you're on your own for now, contact Kevin if you need windows support and I'll make a button to download a .bat script

## Config

Autofill QR codes for up to N seconds:
Separate multiple scanned QR codes with: Reverse sort order of multiple QR codes: